@@ -43,7 +43,7 @@ try:
 except ModuleNotFoundError:
     can_patatt = False
 
-__VERSION__ = '0.7.0'
+__VERSION__ = '0.7.3'
 
 logger = logging.getLogger('b4')
 
@@ -645,7 +645,6 @@ class LoreSeries:
                     cmdargs = ['hash-object', fullpath]
                     ecode, out = git_run_command(None, cmdargs)
                 else:
-                    gitdir = os.path.join(gitdir, '.git')
                     logger.debug('Checking hash on %s:%s', when, fn)
                     # XXX: We should probably pipe the two commands instead of reading into memory,
                     #      so something to consider for the future
@@ -923,13 +922,11 @@ class LoreMessage:
                     self.trailers.append(trailer)
 
     def get_trailers(self, sloppy=False):
-        mismatches = set()
-        if sloppy:
-            return self.trailers, mismatches
-
         trailers = list()
+        mismatches = set()
+
         for tname, tvalue, extdata in self.trailers:
-            if tname.lower() in ('fixes', 'obsoleted-by'):
+            if sloppy or tname.lower() in ('fixes', 'obsoleted-by'):
                 trailers.append((tname, tvalue, extdata, self))
                 continue
 
@@ -1164,7 +1161,7 @@ class LoreMessage:
             if hcs is None:
                 hcs = 'utf-8'
             try:
-                decoded += hstr.decode(hcs)
+                decoded += hstr.decode(hcs, errors='replace')
             except LookupError:
                 # Try as utf-u
                 decoded += hstr.decode('utf-8', errors='replace')
@@ -1255,8 +1252,11 @@ class LoreMessage:
 
     @staticmethod
     def find_trailers(body, followup=False):
-        headers = ('subject', 'date', 'from')
-        nonperson = ('fixes', 'subject', 'date', 'link', 'buglink', 'obsoleted-by')
+        ignores = {'phone', 'email'}
+        headers = {'subject', 'date', 'from'}
+        nonperson = {'fixes', 'subject', 'date', 'link', 'buglink', 'obsoleted-by'}
+        # Ignore everything below standard email signature marker
+        body = body.split('\n-- \n', 1)[0].strip() + '\n'
         # Fix some more common copypasta trailer wrapping
         # Fixes: abcd0123 (foo bar
         # baz quux)
@@ -1279,6 +1279,9 @@ class LoreMessage:
                 groups = list(matches.groups())
                 # We only accept headers if we haven't seen any non-trailer lines
                 tname = groups[0].lower()
+                if tname in ignores:
+                    logger.debug('Ignoring known non-trailer: %s', line)
+                    continue
                 if len(others) and tname in headers:
                     logger.debug('Ignoring %s (header after other content)', line)
                     continue
@@ -1458,14 +1461,13 @@ class LoreMessage:
         parts = ['PATCH']
         if self.lsubject.rfc:
             parts.append('RFC')
-        if not self.revision_inferred:
-            if self.reroll_from_revision:
-                if self.reroll_from_revision != self.revision:
-                    parts.append('v%d->v%d' % (self.reroll_from_revision, self.revision))
-                else:
-                    parts.append(' %s  v%d' % (' ' * len(str(self.reroll_from_revision)), self.revision))
+        if self.reroll_from_revision:
+            if self.reroll_from_revision != self.revision:
+                parts.append('v%d->v%d' % (self.reroll_from_revision, self.revision))
             else:
-                parts.append('v%d' % self.revision)
+                parts.append(' %s  v%d' % (' ' * len(str(self.reroll_from_revision)), self.revision))
+        elif not self.revision_inferred:
+            parts.append('v%d' % self.revision)
         if not self.lsubject.counters_inferred:
             parts.append('%d/%d' % (self.lsubject.counter, self.lsubject.expected))
 
@@ -1731,7 +1733,7 @@ def git_run_command(gitdir: Optional[str], args: List[str], stdin: Optional[byte
                     logstderr: bool = False) -> Tuple[int, str]:
     cmdargs = ['git', '--no-pager']
     if gitdir:
-        if os.path.isdir(os.path.join(gitdir, '.git')):
+        if os.path.exists(os.path.join(gitdir, '.git')):
             gitdir = os.path.join(gitdir, '.git')
         cmdargs += ['--git-dir', gitdir]
     cmdargs += args
@@ -1882,7 +1884,7 @@ def get_cache_dir(appname: str = 'b4') -> str:
         expmin = 600
     expage = time.time() - expmin
     for entry in os.listdir(cachedir):
-        if entry.find('.mbx') <= 0 and entry.find('.lookup') <= 0 and entry.find('.msgs'):
+        if entry.find('.mbx') <= 0 and entry.find('.lookup') <= 0 and entry.find('.msgs') <= 0:
             continue
         fullpath = os.path.join(cachedir, entry)
         st = os.stat(fullpath)
@@ -1952,7 +1954,7 @@ def get_requests_session():
 
 def get_msgid_from_stdin():
     if not sys.stdin.isatty():
-        message = email.message_from_string(sys.stdin.read())
+        message = email.message_from_bytes(sys.stdin.buffer.read())
         return message.get('Message-ID', None)
     return None
 
@@ -2275,7 +2277,7 @@ def save_git_am_mbox(msgs: list, dest):
         bmsg = msg.as_bytes(unixfrom=True, policy=emlpolicy)
         # public-inbox unixfrom says "mboxrd", so replace it with something else
         # so there is no confusion as it's NOT mboxrd
-        bmsg = bmsg.replace(b'From mboxrd@z ', b'From git@z ')
+        bmsg = re.sub(b'^From mboxrd@z ', b'From git@z ', bmsg)
         bmsg = bmsg.rstrip(b'\r\n') + b'\n\n'
         dest.write(bmsg)
 
